
%---------------------------------------
% This is the driver script to generate
% Figure 6.4 of Beard & Qian
clear all
opts = odeset('NonNegative',1:14);

% 0. compute initial steady state
Ar = 0.5;
Nr = 0.8;
xo(1)   = 1.0e-9;      % OAA_x
xo(2)   = 3.0059e-003; % ACCOA_x 
xo(3)   = 7.1480e-004; % CIT_x  
xo(4)   = 1.5914e-005; % ICIT_x  
xo(5)   = 4.8522e-007; % AKG_x   
xo(6)   = 8.6894e-008; % SCOA_x  
xo(7)   = 3.8865e-006; % COASH_x  
xo(8)   = 6.5380e-005; % SUC_x   
xo(9)   = 4.0677e-005; % FUM_x   
xo(10)  = 8.4183e-005; % MAL_x   
xo(11)  = 2.5355e-003; % GTP_x   
xo(12)  = 2.4645e-003; % GDP_x   
xo(13)  = 1.000e-003;  % Mg_x    
xo(14)  = 1.2016e-001; % K_x
[t0,x0] = ode15s(@TCA_dXdT,[0 100],xo,opts,Ar,Nr);

% 1. run for 5 seconds at s-s
Ar = 0.50;
Nr = 0.80;
[t1,x1] = ode15s(@TCA_dXdT,[0 5],x0(end,:),opts,Ar,Nr);
for i = 1:length(t1)
  [J,DG] = TCA_JandDG(x1(i,:),Ar,Nr);
  J1(i,:) = J;
  DG1(i,:) = DG;
end

% 2. run for 15 seconds at new demand state
Ar = 0.50;
Nr = 0.30;
[t2,x2] = ode15s(@TCA_dXdT,[5 20],x1(end,:),opts,Ar,Nr);
for i = 1:length(t2)
  [J,DG] = TCA_JandDG(x2(i,:),Ar,Nr);
  J2(i,:) = J;
  DG2(i,:) = DG;
end
J2(1,:) = J1(end,:);
DG2(1,:) = DG1(end,:);

% 3. Make Figures

figure(1); clf;

subplot(2,2,1); hold on;
plot(t1,J1(:,1)*1e3,'k-',t2,J2(:,1)*1e3,'k-','linewidth',1.5);
set(gca,'Fontsize',15); axis([0 20 0 0.5]);
ylabel('$J_{pdh}$ (mmol$\cdot$sec$^{-1}\cdot$l$^{-1}$)','interpreter','latex'); 
xlabel('$t$ (sec)','interpreter','latex');
text(10,0.4,'Reaction 1','interpreter','latex','Fontsize',15); box on;

subplot(2,2,2); hold on;
plot(t1,J1(:,3)*1e3,'k-',t2,J2(:,3)*1e3,'k-','linewidth',1.5);
set(gca,'Fontsize',15); axis([0 20 0 0.5]);
ylabel('$J_{acon}$ (mmol$\cdot$sec$^{-1}\cdot$l$^{-1}$)','interpreter','latex'); 
xlabel('$t$ (sec)','interpreter','latex');
text(10,0.4,'Reaction 3','interpreter','latex','Fontsize',15); box on;

subplot(2,2,3); hold on;
plot(t1,J1(:,8)*1e3,'k-',t2,J2(:,8)*1e3,'k-','linewidth',1.5);
set(gca,'Fontsize',15); axis([0 20 0 0.5]);
ylabel('$J_{fum}$ (mmol$\cdot$sec$^{-1}\cdot$l$^{-1}$)','interpreter','latex'); 
xlabel('$t$ (sec)','interpreter','latex');
text(10,0.4,'Reaction 8','interpreter','latex','Fontsize',15); box on;

subplot(2,2,4); hold on;
plot(t1,J1(:,9)*1e3,'k-',t2,J2(:,9)*1e3,'k-','linewidth',1.5);
set(gca,'Fontsize',15); axis([0 20 0 0.5]);
ylabel('$J_{mdh}$ (mmol$\cdot$sec$^{-1}\cdot$l$^{-1}$)','interpreter','latex'); 
xlabel('$t$ (sec)','interpreter','latex');
text(10,0.4,'Reaction 9','interpreter','latex','Fontsize',15); box on;


%% Plotting DG;s
RT = 8.314*310.15/1e3;          % kJ  mol^{-1}
figure(2); clf; 

subplot(2,2,1); hold on;
plot(t1,DG1(:,1)./RT,'k-',t2,DG2(:,1)./RT,'k-','linewidth',1.5);
set(gca,'Fontsize',15); 
ylabel('$\Delta G_{pdh}$','interpreter','latex'); 
xlabel('$t$ (sec)','interpreter','latex'); box on;

subplot(2,2,2); hold on;
plot(t1,DG1(:,3)./RT,'k-',t2,DG2(:,3)./RT,'k-','linewidth',1.5);
set(gca,'Fontsize',15); 
ylabel('$\Delta G_{acon}$','interpreter','latex'); 
xlabel('$t$ (sec)','interpreter','latex'); box on;

subplot(2,2,3); hold on;
plot(t1,DG1(:,8)./RT,'k-',t2,DG2(:,8)./RT,'k-','linewidth',1.5);
set(gca,'Fontsize',15); 
ylabel('$\Delta G_{fum}$','interpreter','latex'); 
xlabel('$t$ (sec)','interpreter','latex'); box on;

subplot(2,2,4); hold on;
plot(t1,DG1(:,9)./RT,'k-',t2,DG2(:,9)./RT,'k-','linewidth',1.5);
set(gca,'Fontsize',15); 
ylabel('$\Delta G_{mdh}$','interpreter','latex'); 
xlabel('$t$ (sec)','interpreter','latex'); box on;

