
clear; figure(1); clf; ax1 = axes('position',[0.15 0.15 0.78 0.78]); hold on;

xo(1)  = 180;       % dPsi
xo(2)  = 0.5e-3;    % QH2
xo(3)  = 1e-3;      % Cred
xo(4)  = 5e-5;      % ATP_x
xo(5)  = 1.0e-3;    % Pi_x
xo(6)  = 8.2e-3;    % ATP_i
xo(7)  = 0;         % ADP_i
xo(8)  = 1.0e-3;    % Pi_i
xo(9)  = 10^(-7.2); % H_x
xo(10) = 150e-3;    % K_x
xo(11) = 1.00e-3;    % Mg_x

% DPsi versus NADH at different ADP concentrations
NADr = 0.0:0.02:0.98;

ADP_c = 0.010e-3;
for i = 1:length(NADr)
  [t,x] = ode15s(@oxphos_dXdT,[0 120],xo,[],NADr(i),ADP_c);
  dPsi(i) = x(end,1);
end
plot((1-NADr),dPsi,'k','linewidth',1.5); 

ADP_c = 0.050e-3;
for i = 1:length(NADr)
  [t,x] = ode15s(@oxphos_dXdT,[0 120],xo,[],NADr(i),ADP_c);
  dPsi(i) = x(end,1);
end
plot((1-NADr),dPsi,'k','linewidth',1.5); 

ADP_c = 0.150e-3;
for i = 1:length(NADr)
  [t,x] = ode15s(@oxphos_dXdT,[0 120],xo,[],NADr(i),ADP_c);
  dPsi(i) = x(end,1);
end
plot((1-NADr),dPsi,'k','linewidth',1.5); 

hold off; box on; axis([0 1 160 200]);
set(gca,'Fontsize',14);
ylabel('$\Delta\Psi$ (mV)','interpreter','latex','fontsize',16)
xlabel('[NADH]$/N_o$','interpreter','latex','fontsize',16);

text(0.30,192,'[ADP$_c] = 0.05$ mM','interpreter','latex','fontsize',14);
text(0.30,176.5,'[ADP$_c] = 0.10$ mM','interpreter','latex','fontsize',14);
text(0.30,168.5,'[ADP$_c] = 0.15$ mM','interpreter','latex','fontsize',14);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% J_ANT versus ADP at different NADH concentrations
figure(2); clf; ax1 = axes('position',[0.15 0.15 0.78 0.78]); hold on;
ADP_c = (0:0.003:0.20)*1e-3;

NADr = 0.1;
for i = 1:length(ADP_c)
  [t,x] = ode15s(@oxphos_dXdT,[0 120],xo,[],NADr,ADP_c(i));
  J_ANT(i) = oxphos_JANT(x(end,:),NADr,ADP_c(i));
end
plot(ADP_c*1e3,J_ANT*1e3,'k','linewidth',1.5);

NADr = 0.5;
for i = 1:length(ADP_c)
  [t,x] = ode15s(@oxphos_dXdT,[0 120],xo,[],NADr,ADP_c(i));
  J_ANT(i) = oxphos_JANT(x(end,:),NADr,ADP_c(i));
end
plot(ADP_c*1e3,J_ANT*1e3,'k','linewidth',1.5);

NADr = 0.9;
for i = 1:length(ADP_c)
  [t,x] = ode15s(@oxphos_dXdT,[0 120],xo,[],NADr,ADP_c(i));
  J_ANT(i) = oxphos_JANT(x(end,:),NADr,ADP_c(i));
end
plot(ADP_c*1e3,J_ANT*1e3,'k','linewidth',1.5);

hold off; box on; axis([0 0.20 -0.05 4.0]);
set(gca,'Fontsize',14); set(gca,'ytick',0:1:4);
ylabel('$J_{ANT}$ (mmole$\cdot$sec$^{-1}\cdot$(l mito)$^{-1}$))','interpreter','latex','fontsize',16)
xlabel('[ADP$_c]$ (mM)','interpreter','latex','fontsize',16);

text(0.050,3.5,'[NADH]$/N_o = 0.90$','interpreter','latex','fontsize',14);
text(0.050,3.0,'[NADH]$/N_o = 0.50$','interpreter','latex','fontsize',14);
text(0.1,1.1,'[NADH]$/N_o = 0.10$','interpreter','latex','fontsize',14);
