function [J_ANT] = oxphos_JANT(x,NADr,ADP_c)
%

%% define indices for reactants
iATP	=   1;
iADP    =   2;
iPi     =   3;
iNADH   =   4;
iNAD    =   5;
iQH2    =   6;
iCOQ    =   7;
iCox    =   8;
iCred   =   9;
iO2     =   10;
iH2O    =   11;

%%  LIST of MODEL PARAMETERS
%  (i) Thermochemical constants
RT = 8.314*(28+273.15)/1e3;     % kJ  mol^{-1}
% RT = 8.314*298.15/1e3;        % kJ  mol^{-1}
F = 0.096484;                   % kJ mol^{-1} mV^{-1}
%  (ii) Subcelular volumes and water spaces
Vmito = 0.056;                  % (ml mito / ml cell)
Vcyto = 0.894;                  % (ml cyto / ml cell)
W_m = 0.664*1.09;               % mitochondrial water space (ml water per ml mito) [VB2002]
W_x = 0.9*W_m;                  % Matrix water space
W_i = 0.1*W_m;                  % IM water space
%  (iii) Pooled concentrations
Ctot   = 2.70e-3;               % M; total cytoC
Qtot   = 1.35e-3;               % M; total Q + QH2
NADtot = 2.97e-3;               % M; total NAD+NADH
A_x    = 10e-3;                 % total ATP + ADP pool in matrix
A_c    = 8.2e-3;                % total ATP + ADP pool in cytoplasm
%  (iv) oxphos parameters
n_A = 3.0;  % unitless
k_O2   = 1.2e-4;
x_buff = 100;
%  (v) Outer membrane transport parameters
x_A    = 85;        % micron sec^{-1}
x_Pi2  = 327;       % micron sec^{-1}
gamma  = 5.99;      % mito membrane area per cell volume micron^{-1}

%  STATE VARIABLES
dPsi	= x(1);
QH2_x	= x(2);
Cred_i	= x(3);
ATP_x	= x(4);
Pi_x	= x(5);
ATP_i	= x(6);
ADP_i	= x(7);
Pi_i	= x(8);
H_x     = x(9); 
K_x     = x(10);
Mg_x    = x(11);

% Fixed concentrations
NAD_x = NADtot*NADr;
H_i   = 10^(-7.1);
Mg_i  = 1e-3;
K_i   = 150e-3;
Pi_c  = 1e-3;
O2    = 2.6e-5;

% Other concentrations computed from pooled variables:
NADH_x = NADtot - NAD_x;
ADP_x  = A_x - ATP_x;
ATP_c  = A_c - ADP_c;
COQ_x  = Qtot - QH2_x;
Cox_i  = Ctot - Cred_i;

% Dissociation constants for reatants ATP, ADP, PI
Kh(1) = 10^(-6.46); Km(1) = 10^(-3.58); Kk(1) = 10^(-1.75);
Kh(2) = 10^(-6.33); Km(2) = 10^(-2.61); Kk(2) = 10^(-1.44);
Kh(3) = 10^(-6.65); Km(3) = 10^(-1.58); Kk(3) = inf;

% compute binding polynomials for reactants ATP, ADP, PI
P_x(1) = 1 + H_x/Kh(1) + Mg_x/Km(1) + K_x/Kk(1);
P_x(2) = 1 + H_x/Kh(2) + Mg_x/Km(2) + K_x/Kk(2);
P_x(3) = 1 + H_x/Kh(3)  + Mg_x/Km(3);

P_i(1) = 1 + H_i/Kh(1) + Mg_i/Km(1) + K_i/Kk(1);
P_i(2) = 1 + H_i/Kh(2) + Mg_i/Km(2) + K_i/Kk(2);
P_i(3) = 1 + H_i/Kh(3)  + Mg_i/Km(3);

%% -------------------------------
% 5. ANT
% ATP4-_x + ADP3-_i <-> ATP4-_i + ADP3-_x
x_ANT = 7.27e-3;
k_mADP = 3.6e-6;
ADP_i1 = ADP_i/P_i(2); % fADP_i
ATP_i1 = ATP_i/P_i(1); % fATP_i
ADP_x1 = ADP_x/P_x(2); % fADP_x
ATP_x1 = ATP_x/P_x(1); % fATP_x
theta = 0.60;
Psi_i = theta*dPsi;
Psi_x = (theta-1)*dPsi;
% Flux expression
J_ANT  = x_ANT*( ADP_i1/(ADP_i1+ATP_i1*exp(-F*Psi_i/RT)) - ADP_x1/(ADP_x1+ATP_x1*exp(-F*Psi_x/RT)) )*(ADP_i1/(ADP_i1+k_mADP));





