
setup
options = odeset('NonNegative', 1:61);

%% Simulations

x_AtC = 0.20e-3; % mol s^{-1} (l cell)^{-1} (Beard, PLoS, 2006)

% Run to initial steady state
[t0,x0] = ode15s(@Cell_dXdT,[0 1000],xo,options,param,x_AtC,0);

% Initial curve
[t1,x1] = ode15s(@Cell_dXdT,[0 20],x0(end,:),options,param,x_AtC,0);

% Ischemia curve
[t2,x2] = ode15s(@Cell_dXdT,[20 60],x1(end,:),options,param,x_AtC,1);

% Recovery curve
xo = x2(end,:); xo(1) = 25;
[t3,x3] = ode15s(@Cell_dXdT,[60 180],xo,options,param,x_AtC,0);

t = [t1' t2' t3']';
x = [x1' x2' x3']';
PIobs  = W_c*Rc_cell*x(:,iPI_c)*0.7 + W_m*Rm_cell*x(:,iPI_x);
PCRobs = W_c*Rc_cell*x(:,iPCr_c)*0.7;

%% Plotting ready-for-publish  figures
figure(1); clf;

subplot(2,2,1);
hold on; box on;
errorbar(t_CBFN, CBFN_BF, CBFN_BF_e,'ks',...
    'Markersize',8,'MarkerFaceColor',[1 1 1]);
axis([0 180 0 4]);
set(gca,'Fontsize',14);
set(gca,'Ytick',0:1:4);
set(gca,'Xtick',0:20:200);
xlabel('Time (sec)');
ylabel('Cornary Blood Flow (ml min^{-1} (g tissue)^{-1})');
title('CBF-N');

subplot(2,2,2);
hold on; box on;
errorbar(t_PCrN, PCrN_PCr, PCrN_PCr_e,'ks',...
    'Markersize',8,'MarkerFaceColor',[1 1 1]);
errorbar(t_PiPCr, PiPCr_R, PiPCr_R_e,'ks',...
    'Markersize',8,'MarkerFaceColor',[1 1 1]);  
plot(t,PCRobs./PCRobs(1),'b-','linewidth',1.5);
plot(t,PIobs./PCRobs(1),'r-','linewidth',1.5);
axis([0 180 0 1.2]);
set(gca,'Fontsize',14);
set(gca,'Ytick',0:0.2:1.4);
set(gca,'Xtick',0:20:200);
xlabel('Time (sec)');
ylabel('Normalized [CrP]_c and [PI]_c/[CrP]_c');
title('PCr-N and Pi/PCr');  

subplot(2,2,3);
hold on; box on;
plot(t,x(:,iPO2),'b-','linewidth',1.5);
axis([0 180 0 30]);
set(gca,'Fontsize',14);
set(gca,'Xtick',0:20:200);
xlabel('Time (sec)');
ylabel('PO2 (mmHg)');
title('Oxygen Tension');

% figure(4); clf;
subplot(2,2,4);
hold on; box on;
plot(t,x(:,iPCr_c)*1e3,'b-','linewidth',1.5);
plot(t,PIobs*1e3,'r-','linewidth',1.5);
axis([0 180 0 35]);
set(gca,'Fontsize',14);
set(gca,'Xtick',0:20:200);
xlabel('Time (sec)');
ylabel('[CrP]_c and [PI]_c (mM)');
title('[CrP]_c and [PI]_c');
