clear;

%% define indicis for all state variables
% (i) oxygen species
iPO2 = 1;
% (ii) Matrix species and dPsi
idPsi        = 2;
iH_x         = 3; 
iATP_x       = 4;
iADP_x       = 5;
iAMP_x       = 6;
iGTP_x       = 7;
iGDP_x       = 8;
iPI_x        = 9;
iNADH_x      = 10;
iQH2_x       = 11;
iOAA_x       = 12;
iACCOA_x     = 13;
iCIT_x       = 14;
iICIT_x      = 15;
iAKG_x       = 16;
iSCOA_x      = 17;
iCOASH_x     = 19;
iSUC_x       = 19;
iFUM_x       = 20;
iMAL_x       = 21;
iGLU_x       = 22;
iASP_x       = 23;
iK_x         = 24;
iMg_x        = 25;
iCO2tot_x    = 26;
%  (iii) IM space species
iCred_i      = 27;
iATP_i       = 28;
iADP_i       = 29;
iAMP_i       = 30;
iPI_i        = 31;
iH_i         = 32;
iMg_i        = 33;
iK_i         = 34;
%  (iv) Cytoplasmic species
iATP_c       = 35;
iADP_c       = 36;
iPI_c        = 37;
iH_c         = 38;
iMg_c        = 39;
iK_c         = 40;
% others
iPYR_x      = 41;
iPYR_i      = 42;
iPYR_c      = 43;
iCIT_i      = 44;
iCIT_c      = 45;
iAKG_i      = 46;
iAKG_c      = 47;
iSUC_i      = 48;
iSUC_c      = 49;
iMAL_i      = 50;
iMAL_c      = 51;
iASP_i      = 52;
iASP_c      = 53;
iGLU_i      = 54;
iGLU_c      = 55;
iFUM_i      = 56;
iFUM_c      = 57;
iICIT_i     = 58;
iICIT_c     = 59;
iPCr_c      = 60;
iAMP_c      = 61;

%% Some simulation parameters
a_3 = 1.74e-6;  % Moles dissolved O2 (liter cell)^{-1} mmHg^{-1}
W_m = 0.664*1.09;               % mitochondrial water space (ml water per ml mito) [Vinnakota & Bassingthwaighte]
W_x = 0.9*W_m;                  % Matrix water space
W_i = 0.1*W_m;                  % IM water space
Rm_cyto = 0.20 / 0.472;         % Volume ratio mito volume / cytoplasm volume
Rm_cell = 0.20 / 0.694;         % Volume ratio mito volume / cell volume
Rc_cell = 0.472 / 0.694;        % Volume ratio of cytosol / cell volume
W_c = 0.807*1.044;              % cytosol water space (ml water per ml cytosol) [Vinnakota & Bassingthwaighte]

CMb = 400e-6;                   % Myoglobin concentration (moles per liter cell volume)
P50 = 2.39;                     % oxy-myoglobin 1/2 saturation

%% Inital Conditions
xo(iPO2)    = 25;  % mmHg
xo(iH_x)    = 7.8683e-008;
xo(idPsi)   = 1.8719e+002;
xo(iATP_x)  = 8.4861e-003;
xo(iADP_x)  = 1.5139e-003;
xo(iAMP_x)  = 1e-006;
xo(iGTP_x)  = 4.2630e-003;
xo(iGDP_x)  = 7.3703e-004;
xo(iPI_x)   = 1.7773e-003;
xo(iNADH_x) = 2.6060e-003;
xo(iQH2_x)  = 3.7948e-004;
xo(iOAA_x)  = 1.7809e-011;
xo(iACCOA_x) = 2.9865e-003;
xo(iCIT_x)  = 6.2053e-004;
xo(iICIT_x) = 1.2357e-005;
xo(iAKG_x)  = 2.1134e-005;
xo(iSCOA_x) = 1.3988e-006;
xo(iCOASH_x) = 2.1962e-005;
xo(iSUC_x)  = 8.3893e-005;
xo(iFUM_x)  = 5.9623e-005;
xo(iMAL_x)  = 1.6456e-004;
xo(iGLU_x)  = 1.0247e-004;
xo(iASP_x)  = 1e-8;
xo(iK_x)    = 1.0229e-001;
xo(iMg_x)   = 1e-3;
xo(iCO2tot_x) = 0.0214;
xo(iCred_i) = 4.1548e-004;
xo(iATP_i)  = 9.7e-003;
xo(iADP_i)  = 1e-006;
xo(iAMP_i)  = 1e-09;
xo(iPI_i)   = 6e-004;
xo(iH_i)    = 10^(-7.1);
xo(iMg_i)   = 0.001003;
xo(iK_i)    = 0.13;
xo(iATP_c)  = 9.7e-003; % set for the heart
xo(iADP_c)  = 1e-006; % set for the heart
xo(iPI_c)   = 6e-004; % set for the heart
xo(iH_c)    = 10^(-7.1);
xo(iMg_c)   = 0.001003;
xo(iK_c)    = 0.13;
xo(iPYR_x)  = 7.5738e-005;
xo(iPYR_i)  = 8.6e-005; % fixed
xo(iPYR_c)  = 8.6e-005; % fixed
xo(iCIT_i)  = 1.0000e-004;
xo(iCIT_c)  = 1.0000e-004;
xo(iAKG_i)  = 1.4621e-005;
xo(iAKG_c)  = 1.5000e-005;
xo(iSUC_i)  = 6.2500e-005;
xo(iSUC_c)  = 6.2500e-005;
xo(iMAL_i)  = 1.0038e-004;
xo(iMAL_c)  = 1.0000e-004;
xo(iASP_i)  = 3.1592e-006;
xo(iASP_c)  = 3.1592e-006;
xo(iGLU_i)  = 8.0646e-005;
xo(iGLU_c)  = 8.0646e-005;
xo(iFUM_i)  = 1.5000e-005;
xo(iFUM_c)  = 1.5000e-005;
xo(iICIT_i) = 1.5000e-005;
xo(iICIT_c) = 1.5000e-005;
xo(iPCr_c)  = 28e-3;
xo(iAMP_c)  = 1e-9;


%% Loading experimental data
load CBFN.txt;
t_CBFN = CBFN(:,1);
CBFN_BF = CBFN(:,2);
CBFN_BF_e = CBFN(:,3);

load PCrN.txt;
t_PCrN = PCrN(:,1);
PCrN_PCr = PCrN(:,2);
PCrN_PCr_e = PCrN(:,3);

load PiPCr.txt;
t_PiPCr = PiPCr(:,1);
PiPCr_R = PiPCr(:,2);
PiPCr_R_e = PiPCr(:,3);

load ATPN.txt;
t_ATPN = ATPN(:,1);
ATPN_ATP = ATPN(:,2);
ATPN_ATP_e = ATPN(:,3);


%% Model Parameters
load param10.mat;
param(39) = param(39)*0.10; % decrease leaking activity of proton for in vivo mito